package com.bonus.canteen.core.menu.service;

import java.util.List;
import com.bonus.canteen.core.menu.domain.MenuRecipe;

/**
 * 菜品计划信息Service接口
 * 
 * @author xsheng
 * @date 2025-04-03
 */
public interface IMenuRecipeService {
    /**
     * 查询菜品计划信息
     * 
     * @param id 菜品计划信息主键
     * @return 菜品计划信息
     */
    public MenuRecipe selectMenuRecipeById(Long id);

    /**
     * 查询菜品计划信息列表
     * 
     * @param menuRecipe 菜品计划信息
     * @return 菜品计划信息集合
     */
    public List<MenuRecipe> selectMenuRecipeList(MenuRecipe menuRecipe);

    /**
     * 新增菜品计划信息
     * 
     * @param menuRecipe 菜品计划信息
     * @return 结果
     */
    public int insertMenuRecipe(MenuRecipe menuRecipe);

    /**
     * 修改菜品计划信息
     * 
     * @param menuRecipe 菜品计划信息
     * @return 结果
     */
    public int updateMenuRecipe(MenuRecipe menuRecipe);

    /**
     * 批量删除菜品计划信息
     * 
     * @param ids 需要删除的菜品计划信息主键集合
     * @return 结果
     */
    public int deleteMenuRecipeByIds(Long[] ids);

    /**
     * 删除菜品计划信息信息
     * 
     * @param id 菜品计划信息主键
     * @return 结果
     */
    public int deleteMenuRecipeById(Long id);
}
