package com.bonus.canteen.core.menu.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.bonus.canteen.core.menu.service.IMenuRecipeService;
import com.bonus.common.log.enums.OperaType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.canteen.core.menu.domain.MenuRecipe;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 菜品计划信息Controller
 * 
 * @author xsheng
 * @date 2025-04-03
 */
@Api(tags = "菜品计划信息接口")
@RestController
@RequestMapping("/menu_recipe")
public class MenuRecipeController extends BaseController {
    @Autowired
    private IMenuRecipeService menuRecipeService;

    /**
     * 查询菜品计划信息列表
     */
    @ApiOperation(value = "查询菜品计划信息列表")
    //@RequiresPermissions("menu:recipe:list")
    @GetMapping("/list")
    public TableDataInfo list(MenuRecipe menuRecipe) {
        startPage();
        List<MenuRecipe> list = menuRecipeService.selectMenuRecipeList(menuRecipe);
        return getDataTable(list);
    }

    /**
     * 导出菜品计划信息列表
     */
    @ApiOperation(value = "导出菜品计划信息列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:recipe:export")
    @SysLog(title = "菜品计划信息", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出菜品计划信息")
    @PostMapping("/export")
    public void export(HttpServletResponse response, MenuRecipe menuRecipe) {
        List<MenuRecipe> list = menuRecipeService.selectMenuRecipeList(menuRecipe);
        ExcelUtil<MenuRecipe> util = new ExcelUtil<MenuRecipe>(MenuRecipe.class);
        util.exportExcel(response, list, "菜品计划信息数据");
    }

    /**
     * 获取菜品计划信息详细信息
     */
    @ApiOperation(value = "获取菜品计划信息详细信息")
    //@RequiresPermissions("menu:recipe:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(menuRecipeService.selectMenuRecipeById(id));
    }

    /**
     * 新增菜品计划信息
     */
    @ApiOperation(value = "新增菜品计划信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:recipe:add")
    @SysLog(title = "菜品计划信息", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增菜品计划信息")
    @PostMapping
    public AjaxResult add(@RequestBody MenuRecipe menuRecipe) {
        try {
            return toAjax(menuRecipeService.insertMenuRecipe(menuRecipe));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改菜品计划信息
     */
    @ApiOperation(value = "修改菜品计划信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:recipe:edit")
    @SysLog(title = "菜品计划信息", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改菜品计划信息")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody MenuRecipe menuRecipe) {
        try {
            return toAjax(menuRecipeService.updateMenuRecipe(menuRecipe));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除菜品计划信息
     */
    @ApiOperation(value = "删除菜品计划信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:recipe:remove")
    @SysLog(title = "菜品计划信息", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除菜品计划信息")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(menuRecipeService.deleteMenuRecipeByIds(ids));
    }
}
